@@ -2,7 +2,7 @@ module OrdinaryDiffEqRosenbrock
 
 import OrdinaryDiffEqCore: alg_order, alg_adaptive_order, isWmethod, isfsal, _unwrap_val,
                            DEFAULT_PRECS, OrdinaryDiffEqRosenbrockAlgorithm, @cache,
-                           alg_cache, initialize!, @unpack,
+                           alg_cache, initialize!,
                            calculate_residuals!, OrdinaryDiffEqMutableCache,
                            OrdinaryDiffEqConstantCache, _ode_interpolant, _ode_interpolant!,
                            _vec, _reshape, perform_step!, trivial_limiter!,
