@@ -1,7 +1,7 @@
 function initialize!(integrator, cache::Union{Rosenbrock23Cache,
         Rosenbrock32Cache})
     integrator.kshortsize = 2
-    @unpack k₁, k₂, fsalfirst, fsallast = cache
+    (; k₁, k₂, fsalfirst, fsallast) = cache
     resize!(integrator.k, integrator.kshortsize)
     integrator.k[1] = k₁
     integrator.k[2] = k₂
@@ -24,9 +24,9 @@ function initialize!(integrator,
 end
 
 @muladd function perform_step!(integrator, cache::Rosenbrock23Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, opts = integrator
-    @unpack k₁, k₂, k₃, du1, du2, f₁, fsalfirst, fsallast, dT, J, W, tmp, uf, tf, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter! = cache
-    @unpack c₃₂, d = cache.tab
+    (; t, dt, uprev, u, f, p, opts) = integrator
+    (; k₁, k₂, k₃, du1, du2, f₁, fsalfirst, fsallast, dT, J, W, tmp, uf, tf, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter!) = cache
+    (; c₃₂, d) = cache.tab
 
     # Assignments
     sizeu = size(u)
@@ -136,9 +136,9 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::Rosenbrock32Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p, opts = integrator
-    @unpack k₁, k₂, k₃, du1, du2, f₁, fsalfirst, fsallast, dT, J, W, tmp, uf, tf, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter! = cache
-    @unpack c₃₂, d = cache.tab
+    (; t, dt, uprev, u, f, p, opts) = integrator
+    (; k₁, k₂, k₃, du1, du2, f₁, fsalfirst, fsallast, dT, J, W, tmp, uf, tf, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter!) = cache
+    (; c₃₂, d) = cache.tab
 
     # Assignments
     sizeu = size(u)
@@ -240,8 +240,8 @@ end
 
 @muladd function perform_step!(integrator, cache::Rosenbrock23ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack c₃₂, d, tf, uf = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; c₃₂, d, tf, uf) = cache
 
     # Precalculations
     dtγ = dt * d
@@ -319,8 +319,8 @@ end
 
 @muladd function perform_step!(integrator, cache::Rosenbrock32ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack c₃₂, d, tf, uf = cache
+    (; t, dt, uprev, u, f, p) = integrator
+    (; c₃₂, d, tf, uf) = cache
 
     # Precalculations
     dtγ = dt * d
@@ -414,7 +414,7 @@ function initialize!(integrator,
             Rosenbrock34Cache,
             Rosenbrock4Cache})
     integrator.kshortsize = 2
-    @unpack fsalfirst, fsallast = cache
+    (; fsalfirst, fsallast) = cache
     resize!(integrator.k, integrator.kshortsize)
     integrator.k[1] = fsalfirst
     integrator.k[2] = fsallast
@@ -424,9 +424,9 @@ end
 
 @muladd function perform_step!(integrator, cache::Rosenbrock33ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack tf, uf = cache
-    @unpack a21, a31, a32, C21, C31, C32, b1, b2, b3, btilde1, btilde2, btilde3, gamma, c2, c3, d1, d2, d3 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; tf, uf) = cache
+    (; a21, a31, a32, C21, C31, C32, b1, b2, b3, btilde1, btilde2, btilde3, gamma, c2, c3, d1, d2, d3) = cache.tab
 
     # Precalculations
     dtC21 = C21 / dt
@@ -495,9 +495,9 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::Rosenbrock33Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack du, du1, du2, fsalfirst, fsallast, k1, k2, k3, dT, J, W, uf, tf, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter! = cache
-    @unpack a21, a31, a32, C21, C31, C32, b1, b2, b3, btilde1, btilde2, btilde3, gamma, c2, c3, d1, d2, d3 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; du, du1, du2, fsalfirst, fsallast, k1, k2, k3, dT, J, W, uf, tf, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter!) = cache
+    (; a21, a31, a32, C21, C31, C32, b1, b2, b3, btilde1, btilde2, btilde3, gamma, c2, c3, d1, d2, d3) = cache.tab
 
     # Assignments
     mass_matrix = integrator.f.mass_matrix
@@ -599,9 +599,9 @@ end
 
 @muladd function perform_step!(integrator, cache::Rosenbrock34ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack tf, uf = cache
-    @unpack a21, a31, a32, a41, a42, a43, C21, C31, C32, C41, C42, C43, b1, b2, b3, b4, btilde1, btilde2, btilde3, btilde4, gamma, c2, c3, d1, d2, d3, d4 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; tf, uf) = cache
+    (; a21, a31, a32, a41, a42, a43, C21, C31, C32, C41, C42, C43, b1, b2, b3, b4, btilde1, btilde2, btilde3, btilde4, gamma, c2, c3, d1, d2, d3, d4) = cache.tab
 
     # Precalculations
     dtC21 = C21 / dt
@@ -685,9 +685,9 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::Rosenbrock34Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack du, du1, du2, fsalfirst, fsallast, k1, k2, k3, k4, dT, J, W, uf, tf, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter! = cache
-    @unpack a21, a31, a32, a41, a42, a43, C21, C31, C32, C41, C42, C43, b1, b2, b3, b4, btilde1, btilde2, btilde3, btilde4, gamma, c2, c3, d1, d2, d3, d4 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; du, du1, du2, fsalfirst, fsallast, k1, k2, k3, k4, dT, J, W, uf, tf, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter!) = cache
+    (; a21, a31, a32, a41, a42, a43, C21, C31, C32, C41, C42, C43, b1, b2, b3, b4, btilde1, btilde2, btilde3, btilde4, gamma, c2, c3, d1, d2, d3, d4) = cache.tab
 
     # Assignments
     uidx = eachindex(integrator.uprev)
@@ -848,9 +848,9 @@ end
 @muladd function perform_step!(
         integrator, cache::Union{Rodas23WConstantCache, Rodas3PConstantCache},
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack tf, uf = cache
-    @unpack a21, a41, a42, a43, C21, C31, C32, C41, C42, C43, C51, C52, C53, C54, gamma, c2, c3, d1, d2, d3 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; tf, uf) = cache
+    (; a21, a41, a42, a43, C21, C31, C32, C41, C42, C43, C51, C52, C53, C54, gamma, c2, c3, d1, d2, d3) = cache.tab
 
     # Precalculations
     dtC21 = C21 / dt
@@ -937,7 +937,7 @@ end
 
     EEst = 0.0
     if integrator.opts.calck
-        @unpack h21, h22, h23, h24, h25, h31, h32, h33, h34, h35, h2_21, h2_22, h2_23, h2_24, h2_25 = cache.tab
+        (; h21, h22, h23, h24, h25, h31, h32, h33, h34, h35, h2_21, h2_22, h2_23, h2_24, h2_25) = cache.tab
         integrator.k[1] = h21 * k1 + h22 * k2 + h23 * k3 + h24 * k4 + h25 * k5
         integrator.k[2] = h31 * k1 + h32 * k2 + h33 * k3 + h34 * k4 + h35 * k5
         integrator.k[3] = h2_21 * k1 + h2_22 * k2 + h2_23 * k3 + h2_24 * k4 + h2_25 * k5
@@ -979,7 +979,7 @@ end
 
 function initialize!(integrator, cache::Union{Rodas23WCache, Rodas3PCache})
     integrator.kshortsize = 3
-    @unpack dense1, dense2, dense3 = cache
+    (; dense1, dense2, dense3) = cache
     resize!(integrator.k, integrator.kshortsize)
     integrator.k[1] = dense1
     integrator.k[2] = dense2
@@ -988,9 +988,9 @@ end
 
 @muladd function perform_step!(
         integrator, cache::Union{Rodas23WCache, Rodas3PCache}, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack du, du1, du2, dT, J, W, uf, tf, k1, k2, k3, k4, k5, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter! = cache
-    @unpack a21, a41, a42, a43, C21, C31, C32, C41, C42, C43, C51, C52, C53, C54, gamma, c2, c3, d1, d2, d3 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; du, du1, du2, dT, J, W, uf, tf, k1, k2, k3, k4, k5, linsolve_tmp, jac_config, atmp, weight, stage_limiter!, step_limiter!) = cache
+    (; a21, a41, a42, a43, C21, C31, C32, C41, C42, C43, C51, C52, C53, C54, gamma, c2, c3, d1, d2, d3) = cache.tab
 
     # Assignments
     sizeu = size(u)
@@ -1106,7 +1106,7 @@ end
 
     EEst = 0.0
     if integrator.opts.calck
-        @unpack h21, h22, h23, h24, h25, h31, h32, h33, h34, h35, h2_21, h2_22, h2_23, h2_24, h2_25 = cache.tab
+        (; h21, h22, h23, h24, h25, h31, h32, h33, h34, h35, h2_21, h2_22, h2_23, h2_24, h2_25) = cache.tab
         @.. broadcast=false integrator.k[1]=h21 * k1 + h22 * k2 + h23 * k3 + h24 * k4 +
                                             h25 * k5
         @.. broadcast=false integrator.k[2]=h31 * k1 + h32 * k2 + h33 * k3 + h34 * k4 +
@@ -1240,7 +1240,7 @@ end
     linsolve_tmp = @.. du + dtd[1] * dT
     k1 = _reshape(W \ -_vec(linsolve_tmp), axes(uprev))
     # constant number for type stability make sure this is greater than num_stages
-    ks = ntuple(Returns(k1), 20)
+    ks = ntuple(Returns(k1), Val(20))
     # Loop for stages
     for stage in 2:num_stages
         u = uprev
